@@ -34,9 +34,14 @@
 #include <projectexplorer/session.h>
 #include <projectexplorer/project.h>
 #include <projectexplorer/iprojectmanager.h>
+#include <projectexplorer/target.h>
 
 using namespace Ubuntu::Internal;
 
+enum {
+    debug = 0
+};
+
 UbuntuClickManifest::UbuntuClickManifest(QObject *parent) :
     QObject(parent), m_bInitialized(false), m_bNameDashReplaced(false)
 
@@ -46,7 +51,7 @@ UbuntuClickManifest::UbuntuClickManifest(QObject *parent) :
      debugger.setAutoShowStandardWindow(true);
 
     QFile manifestAppFile(QLatin1String(":/ubuntu/manifestlib.js"));
-    if (!manifestAppFile.open(QIODevice::ReadOnly)) { qDebug() << QLatin1String("unable to open js app"); return; }
+    if (!manifestAppFile.open(QIODevice::ReadOnly)) { if(debug) qDebug() << QLatin1String("unable to open js app"); return; }
     QString manifestApp = QString::fromLatin1(manifestAppFile.readAll());
     manifestAppFile.close();
 
@@ -125,19 +130,19 @@ QString UbuntuClickManifest::policyVersion () {
     return callGetStringFunction(QLatin1String("getPolicyVersion"));
 }
 
-void UbuntuClickManifest::setPolicyGroups(QString appName, QStringList groups) {
+void UbuntuClickManifest::setPolicyGroups(QStringList groups) {
     if (!isInitialized()) { return; }
 
     QStringList args;
-    args << appName << groups.join(QLatin1String(" "));
+    args << groups.join(QLatin1String(" "));
     callSetStringListFunction(QLatin1String("setPolicyGroups"),args);
     emit policyGroupsChanged();
 
 }
 
-QStringList UbuntuClickManifest::policyGroups(QString appName) {
+QStringList UbuntuClickManifest::policyGroups() {
     if (!isInitialized()) { return QStringList(); }
-    QStringList retval = callGetStringListFunction(QLatin1String("getPolicyGroups"),appName);
+    QStringList retval = callGetStringListFunction(QLatin1String("getPolicyGroups"));
     return retval;
 }
 
@@ -154,16 +159,31 @@ QList<UbuntuClickManifest::Hook> UbuntuClickManifest::hooks()
     while (it.hasNext()) {
         it.next();
         QScriptValue appDescriptor = it.value();
-        if(!appDescriptor.isObject()
-                || !appDescriptor.property(QLatin1String("desktop")).isValid()
-                || !appDescriptor.property(QLatin1String("apparmor")).isValid()) {
+        if(!appDescriptor.isObject()) {
             printToOutputPane(tr("Invalid hook in manifest.json file."));
             continue;
         }
 
+        if(!appDescriptor.property(QLatin1String("apparmor")).isValid()) {
+            printToOutputPane(tr("The apparmor path is missing in the manifest file"));
+            continue;
+        }
+
+        bool isScope = appDescriptor.property(QLatin1String("scope")).isValid();
+        bool isApp = appDescriptor.property(QLatin1String("desktop")).isValid();
+
+        if( (isScope && isApp) || (!isScope && !isApp)) {
+            printToOutputPane(tr("The manifest file needs to specify if this is a app or a scope"));
+            continue;
+        }
+
         Hook app;
         app.appId = it.name();
-        app.desktopFile  = it.value().property(QLatin1String("desktop")).toString();
+        if(isApp)
+            app.desktopFile  = it.value().property(QLatin1String("desktop")).toString();
+        if(isScope)
+            app.scope  = it.value().property(QLatin1String("scope")).toString();
+
         app.appArmorFile = it.value().property(QLatin1String("apparmor")).toString();
         hooks.append(app);
     }
@@ -171,6 +191,25 @@ QList<UbuntuClickManifest::Hook> UbuntuClickManifest::hooks()
     return hooks;
 }
 
+void UbuntuClickManifest::setHook(const UbuntuClickManifest::Hook &hook)
+{
+    Q_UNUSED(hook);
+
+    QScriptValue scriptValue = engine.newObject();
+
+    scriptValue.setProperty(QStringLiteral("appId"),hook.appId);
+    scriptValue.setProperty(QStringLiteral("apparmor"),hook.appArmorFile);
+    if(!hook.desktopFile.isEmpty()) {
+        scriptValue.setProperty(QStringLiteral("desktop"),hook.desktopFile);
+    } else if(!hook.appArmorFile.isEmpty()) {
+        scriptValue.setProperty(QStringLiteral("scope"),hook.scope);
+    } else
+        //not known
+        return;
+
+    callSetFunction(QStringLiteral("setHook"),QScriptValueList{scriptValue});
+}
+
 void UbuntuClickManifest::setFrameworkName(const QString &name)
 {
     if (!isInitialized()) { return; }
@@ -203,6 +242,11 @@ bool UbuntuClickManifest::setAppArmorFileName(const QString &appId, const QStrin
     return result;
 }
 
+bool UbuntuClickManifest::enableDebugging()
+{
+    return callFunction(QLatin1String("injectDebugPolicy"),QScriptValueList()).toBool();
+}
+
 void UbuntuClickManifest::save(QString fileName) {
     if (!isInitialized()) { return; }
 
@@ -212,7 +256,7 @@ void UbuntuClickManifest::save(QString fileName) {
 
     if (!file.open(QIODevice::WriteOnly)) {
         emit error();
-        qDebug() << QLatin1String("unable to open file for writing") <<  fileName;
+        if(debug) qDebug() << QLatin1String("unable to open file for writing") <<  fileName;
         return;
     }
 
@@ -224,7 +268,7 @@ void UbuntuClickManifest::save(QString fileName) {
 }
 
 void UbuntuClickManifest::reload() {
-    load(m_fileName,m_projectName);
+    load(m_fileName);
 }
 
 QString UbuntuClickManifest::raw() {
@@ -238,21 +282,20 @@ void UbuntuClickManifest::setRaw(QString data) {
     emit loaded();
 }
 
-bool UbuntuClickManifest::load(const QString &fileName, const QString &projectName) {
-    setFileName(fileName);
-    m_projectName = projectName;
+bool UbuntuClickManifest::load(const QString &fileName,ProjectExplorer::Project *proj) {
 
+    setFileName(fileName);
     QFile file(fileName);
 
     if (!file.exists()) {
         emit error();
-        qDebug() << QLatin1String("file does not exist");
+        if(debug) qDebug() << QLatin1String("file does not exist");
         return false;
     }
 
     if (!file.open(QIODevice::ReadOnly)) {
         emit error();
-        qDebug() << QLatin1String("unable to open file for reading");
+        if(debug) qDebug() << QLatin1String("unable to open file for reading");
 
         return false;
     }
@@ -260,29 +303,31 @@ bool UbuntuClickManifest::load(const QString &fileName, const QString &projectNa
     QString data = QString::fromUtf8(file.readAll());
     file.close();
 
-    if (fileName == QLatin1String(":/ubuntu/manifest.json.template")) {
+    if (fileName == QLatin1String(Constants::UBUNTUPACKAGINGWIDGET_DEFAULT_MANIFEST)) {
+        if(!proj)
+            return false;
 
-        QString mimeType = ProjectExplorer::SessionManager::startupProject()->projectManager()->mimeType();
-        QString proName  = ProjectExplorer::SessionManager::startupProject()->projectFilePath();
+        QString mimeType = proj->projectManager()->mimeType();
+        QString proName  = proj->projectFilePath();
 
         bool isUbuntuProject = (mimeType == QLatin1String(Constants::UBUNTUPROJECT_MIMETYPE));
         bool isUbuntuHtmlProject = proName.endsWith(QLatin1String(Constants::UBUNTUHTMLPROJECT_SUFFIX));
 
         QString defFramework;
         if(isUbuntuProject && isUbuntuHtmlProject) {
-            defFramework = UbuntuClickTool::getMostRecentFramework(QLatin1String("html"));
+            defFramework = UbuntuClickTool::getMostRecentFramework(QLatin1String("html"),UbuntuClickTool::clickTargetFromTarget(proj->activeTarget()));
 
             if(defFramework.isEmpty())
                 defFramework = QLatin1String(Constants::UBUNTU_DEFAULT_HTML_FRAMEWORK);
         } else {
-            defFramework = UbuntuClickTool::getMostRecentFramework(QLatin1String("qml"));
+            defFramework = UbuntuClickTool::getMostRecentFramework(QLatin1String("qml"),UbuntuClickTool::clickTargetFromTarget(proj->activeTarget()));
 
             if(defFramework.isEmpty())
                 defFramework = QLatin1String(Constants::UBUNTU_DEFAULT_QML_FRAMEWORK);
         }
         data.replace(QLatin1String("myFramework"),defFramework);
 
-        QString tmpProjectName = projectName;
+        QString tmpProjectName = proj->displayName();
         tmpProjectName.replace(QLatin1String("_"),QLatin1String("-"));
         data.replace(QLatin1String("myapp"),tmpProjectName);
         QString original_security_manifest_name = QString(QLatin1String("%0.json")).arg(tmpProjectName);
@@ -296,11 +341,20 @@ bool UbuntuClickManifest::load(const QString &fileName, const QString &projectNa
         }
     }
 
-    callSetStringFunction(QLatin1String("fromJSON"),data);
+    return loadFromString(data);
+}
 
-    m_bInitialized = true;
-    emit loaded();
-    return true;
+bool UbuntuClickManifest::loadFromString(const QString &data)
+{
+    //@TODO probably return the error message
+    QScriptValue ret = callFunction(QStringLiteral("fromJSON"),QScriptValueList{QScriptValue(data)});
+    bool success = ret.toBool();
+    if(success) {
+        m_bInitialized = true;
+        emit loaded();
+    }
+
+    return success;
 }
 
 QScriptValue UbuntuClickManifest::callFunction(QString functionName, QScriptValueList args) {
@@ -347,3 +401,15 @@ QStringList UbuntuClickManifest::callGetStringListFunction(QString functionName,
     return retval.toVariant().toStringList();
 }
 
+/*!
+ * \brief UbuntuClickManifest::Hook::type
+ * Returns the hook type depending on which fields are not empty
+ */
+UbuntuClickManifest::Hook::Type UbuntuClickManifest::Hook::type() const
+{
+    if(!desktopFile.isEmpty())
+        return Application;
+    else if(!scope.isEmpty())
+        return Scope;
+    return Invalid;
+}
