@@ -25,6 +25,8 @@
 #include <QStringList>
 #include <QScriptValue>
 
+namespace ProjectExplorer { class Project; }
+
 namespace Ubuntu {
 namespace Internal {
 
@@ -35,9 +37,19 @@ public:
     explicit UbuntuClickManifest(QObject *parent = 0);
 
     struct Hook {
+        enum Type{
+            Invalid,
+            Scope,
+            Application,
+            Helper
+        };
+
         QString appId;
         QString desktopFile;
+        QString scope;
         QString appArmorFile;
+
+        Type type() const;
     };
 
 signals:
@@ -71,10 +83,11 @@ public slots:
     void setDescription(QString description);
     QString description();
 
-    void setPolicyGroups(QString appName, QStringList groups);
-    QStringList policyGroups(QString appName);
+    void setPolicyGroups(QStringList groups);
+    QStringList policyGroups();
 
     QList<Hook> hooks ();
+    void setHook (const Hook &hook);
     
     void setPolicyVersion(const QString &version);
     QString policyVersion();
@@ -85,9 +98,12 @@ public slots:
     QString appArmorFileName ( const QString &appId );
     bool setAppArmorFileName( const QString &appId, const QString &name );
 
+    bool enableDebugging();
+
     void save() { save(m_fileName); }
     void save(QString fileName);
-    bool load(const QString &fileName, const QString &projectName);
+    bool load(const QString &fileName,ProjectExplorer::Project *proj = 0);
+    bool loadFromString(const QString &data);
     void reload();
 
     QString raw();
