@@ -20,10 +20,11 @@
 #include "ubuntuemulatornotifier.h"
 #include "ubuntuprocess.h"
 #include "ubuntuconstants.h"
-#include "ubuntudeviceconfigurationwidget.h"
+#include "ubuntudevicesignaloperation.h"
 #include "localportsmanager.h"
 
 #include <projectexplorer/devicesupport/devicemanager.h>
+#include <remotelinux/genericlinuxdeviceconfigurationwidget.h>
 #include <coreplugin/messagemanager.h>
 #include <ssh/sshconnection.h>
 #include <utils/portlist.h>
@@ -32,11 +33,25 @@
 #include <QCoreApplication>
 #include <QDir>
 #include <QDebug>
+#include <QRegularExpression>
+#include <QSet>
 
 namespace Ubuntu {
 namespace Internal {
 
-const QLatin1String DEVICE_INFO_KEY("UbuntuDevice.InfoString");
+enum {
+    debug = 0
+};
+
+const QString DEVICE_SETTINGS_VERSION(QStringLiteral("UbuntuDevice.Version"));
+const QString DEVICE_INFO_KEY(QStringLiteral("UbuntuDevice.InfoString"));
+const QString DEVICE_SERIAL_ARCHITECTURE(QStringLiteral("UbuntuDevice.Arch"));
+const QString DEVICE_SCALE_FACTOR(QStringLiteral("UbuntuDevice.EmulatorScaleFactor"));
+const QString DEVICE_MEMORY_SETTING(QStringLiteral("UbuntuDevice.EmulatorMemory"));
+const QSet<QString> supportedScaleFactors {QStringLiteral("1.0"), QStringLiteral("0.9"), QStringLiteral("0.8"), QStringLiteral("0.7"),
+            QStringLiteral("0.6"),QStringLiteral("0.5"), QStringLiteral("0.4"), QStringLiteral("0.3"), QStringLiteral("0.2"),
+            QStringLiteral("0.1")};
+const QSet<QString> supportedMemorySettings {QStringLiteral("512"), QStringLiteral("768"), QStringLiteral("1024")};
 
 /*!
  * \class UbuntuDeviceHelper
@@ -47,6 +62,7 @@ const QLatin1String DEVICE_INFO_KEY("UbuntuDevice.InfoString");
 UbuntuDeviceHelper::UbuntuDeviceHelper(UbuntuDevice *dev)
     : QObject(0)
     , m_clonedNwCount(0)
+    , m_errorCount(0)
     , m_dev(dev)
     , m_process(0)
     , m_deviceWatcher(0)
@@ -87,17 +103,23 @@ void UbuntuDeviceHelper::refresh()
 
 void UbuntuDeviceHelper::init()
 {
-    if(!m_dev->serialNumber().isEmpty()) {
-
-        if(!m_deviceWatcher) {
-            if(m_dev->serialNumber().startsWith(QLatin1String("emulator")))
+    if(!m_deviceWatcher) {
+        QString watchKey;
+        if(m_dev->machineType() == ProjectExplorer::IDevice::Emulator) {
+            if (!m_dev->imageName().isEmpty()) {
                 m_deviceWatcher = new UbuntuEmulatorNotifier(this);
-            else
+                watchKey = m_dev->imageName();
+            }
+        } else {
+            if (!m_dev->serialNumber().isEmpty()) {
                 m_deviceWatcher = new UbuntuDeviceNotifier(this);
+                watchKey = m_dev->serialNumber();
+            }
+        }
 
+        if (m_deviceWatcher) {
             m_deviceWatcher->stopMonitoring();
-            m_deviceWatcher->startMonitoring(m_dev->id().toSetting().toString());
-
+            m_deviceWatcher->startMonitoring(watchKey);
             connect(m_deviceWatcher,SIGNAL(deviceConnected()),this,SLOT(deviceConnected()));
             connect(m_deviceWatcher,SIGNAL(deviceDisconnected()),this,SLOT(deviceDisconnected()));
         }
@@ -108,41 +130,114 @@ void UbuntuDeviceHelper::init()
     }
 }
 
+void UbuntuDeviceHelper::waitForEmulatorStart()
+{
+    setProcessState(UbuntuDevice::WaitForEmulatorStart);
+    beginAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_WAIT_FOR_EMULATOR_MESSAGE));
+
+    stopProcess();
+    startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_WAIT_FOR_EMULATOR_SCRIPT)
+                 .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
+                 .arg(m_dev->imageName()));
+}
+
+void UbuntuDeviceHelper::waitForBoot()
+{
+    //at this point the serial ID should be known
+    m_dev->setupPrivateKey();
+
+    setProcessState(UbuntuDevice::WaitForBoot);
+    beginAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_WAIT_FOR_BOOT_MESSAGE));
+
+    stopProcess();
+    startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_WAIT_FOR_BOOT_SCRIPT)
+                 .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
+                 .arg(m_dev->serialNumber()));
+}
+
 void UbuntuDeviceHelper::processFinished(const QString &, const int code)
 {
     Q_UNUSED(code)
 
+    if (code == 0) {
+        m_errorCount = 0;
+    } else {
+        if(m_errorCount > 3) {
+            setProcessState(UbuntuDevice::Failed);
+            m_reply.clear();
+            return;
+        }
+    }
+
     switch(m_dev->m_processState) {
+        case UbuntuDevice::WaitForEmulatorStart: {
+
+            if(code != 0) {
+                m_errorCount++;
+                waitForEmulatorStart();
+                break;
+            }
+
+            m_dev->m_emulatorSerial = m_reply.trimmed();
+            emit deviceInfoUpdated();
+
+            waitForBoot();
+            break;
+        }
+        case UbuntuDevice::WaitForBoot: {
+            if(code != 0) {
+                m_errorCount++;
+                waitForBoot();
+                break;
+            }
+            //for now the script will wait forever until the shell is available
+            detect();
+            break;
+        }
         case UbuntuDevice::DetectDeviceVersion:{
-            //seems to do just nothing, devicewidget did not check return code
-            //emit a message here
+            if(code != 0) {
+                m_errorCount++;
+                detect();
+                break;
+            }
+
+            QStringList options = m_reply.split(QStringLiteral("\n"),QString::SkipEmptyParts);
+            if(debug) qDebug()<<options;
+            if(options.length() == 5) {
+                m_dev->setDeviceInfo(options[1].trimmed(),
+                        options[0].trimmed(),
+                        options[2].trimmed());
+
+                m_dev->m_architecture = options[4].trimmed();
+            }
+
             detectHasNetworkConnection();
             break;
         }
         case UbuntuDevice::DetectNetworkConnection:{
+            if(code != 0) {
+                m_errorCount++;
+                detectHasNetworkConnection();
+                break;
+            }
+
             if (m_reply.trimmed() == QString::fromLatin1(Constants::ONE_STR)) {
                 // we have network
                 m_clonedNwCount = 0;
                 if(m_dev->m_hasNetworkConnection != UbuntuDevice::Available) {
                     m_dev->m_hasNetworkConnection = UbuntuDevice::Available;
-                    emit featureDetected();
                 }
+                emit featureDetected();
                 detectOpenSsh();
 
             } else {
-                // not set
-                if (m_clonedNwCount == 0)
-                    cloneNetwork();
-                else {
-                    //we tried to enable network and failed
-                    if(m_dev->m_hasNetworkConnection != UbuntuDevice::NotAvailable) {
-                        m_dev->m_hasNetworkConnection = UbuntuDevice::NotAvailable;
-                        emit featureDetected();
-                        emit deviceNeedsSetup();
-                    }
-                    //detect other features
-                    detectOpenSsh();
+                if(m_dev->m_hasNetworkConnection != UbuntuDevice::NotAvailable) {
+                    m_dev->m_hasNetworkConnection = UbuntuDevice::NotAvailable;
                 }
+                emit featureDetected();
+                emit deviceNeedsSetup();
+                //detect other features
+                detectOpenSsh();
             }
             break;
         }
@@ -152,13 +247,19 @@ void UbuntuDeviceHelper::processFinished(const QString &, const int code)
             break;
         }
         case UbuntuDevice::DetectOpenSSH:{
+            if(code != 0) {
+                m_errorCount++;
+                detectOpenSsh();
+                break;
+            }
+
             if (m_reply.trimmed() != QLatin1String(Constants::UBUNTUDEVICESWIDGET_ONFINISHED_NONE)
                     && m_reply.trimmed() != QLatin1String(Constants::EMPTY)) {
 
                 if(m_dev->m_hasOpenSSHServer != UbuntuDevice::Available) {
                     m_dev->m_hasOpenSSHServer = UbuntuDevice::Available;
-                    emit featureDetected();
                 }
+                emit featureDetected();
 
                 ProjectExplorer::DeviceManager::instance()->setDeviceState(m_dev->id(),ProjectExplorer::IDevice::DeviceConnected);
                 endAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_ONFINISHED_SSH_IS_INSTALLED).arg(m_reply.trimmed()));
@@ -170,9 +271,9 @@ void UbuntuDeviceHelper::processFinished(const QString &, const int code)
 
                 if(m_dev->m_hasOpenSSHServer != UbuntuDevice::NotAvailable) {
                     m_dev->m_hasOpenSSHServer = UbuntuDevice::NotAvailable;
-                    emit featureDetected();
-                    emit deviceNeedsSetup();
                 }
+                emit featureDetected();
+                emit deviceNeedsSetup();
 
                 endAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_ONFINISHED_SSH_NOT_INSTALLED));
 
@@ -194,6 +295,11 @@ void UbuntuDeviceHelper::processFinished(const QString &, const int code)
             break;
         }
         case UbuntuDevice::StartOpenSSH:{
+            if(code != 0) {
+                m_errorCount++;
+                startSshService();
+                break;
+            }
 
             if(m_dev->m_openSSHStarted != UbuntuDevice::Available) {
                 m_dev->m_openSSHStarted = UbuntuDevice::Available;
@@ -211,6 +317,11 @@ void UbuntuDeviceHelper::processFinished(const QString &, const int code)
             break;
         }
         case UbuntuDevice::DeployPublicKey:{
+            if(code != 0) {
+                m_errorCount++;
+                deployPublicKey();
+                break;
+            }
             //ready to use
             ProjectExplorer::DeviceManager::instance()->setDeviceState(m_dev->id(),ProjectExplorer::IDevice::DeviceReadyToUse);
             endAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_ONFINISHED_PUBLICKEY_AUTH_SET));
@@ -219,6 +330,12 @@ void UbuntuDeviceHelper::processFinished(const QString &, const int code)
             break;
         }
         case UbuntuDevice::DetectDeviceWriteableImage:{
+            if(code != 0) {
+                m_errorCount++;
+                detectDeviceWritableImage();
+                break;
+            }
+
             if (m_reply.trimmed() == QLatin1String(Constants::ZERO_STR)) {
                 m_dev->m_hasWriteableImage = UbuntuDevice::Available;
                 endAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_ONFINISHED_WRITABLEIMAGE));
@@ -232,6 +349,12 @@ void UbuntuDeviceHelper::processFinished(const QString &, const int code)
             break;
         }
         case UbuntuDevice::DetectDeveloperTools:{
+            if(code != 0) {
+                m_errorCount++;
+                detectDeveloperTools();
+                break;
+            }
+
             setProcessState(UbuntuDevice::Done);
             stopProcess();
 
@@ -242,7 +365,6 @@ void UbuntuDeviceHelper::processFinished(const QString &, const int code)
                 m_dev->m_hasDeveloperTools = UbuntuDevice::Available;
                 endAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_ONFINISHED_DEVELOPERTOOLS_INSTALLED));
             }
-
             emit featureDetected();
             break;
         }
@@ -275,19 +397,20 @@ void UbuntuDeviceHelper::processFinished(const QString &, const int code)
 
 void UbuntuDeviceHelper::onMessage(const QString &msg) {
     m_reply.append(msg);
-
-    QString message = msg;
-    message.replace(QChar::fromLatin1('\n'),QLatin1String("<br/>"));
-
-    addToLog(message);
 }
 
 void UbuntuDeviceHelper::onError(const QString &error)
 {
-    qDebug()<<"Received error "<<error;
     addToLog(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_ONERROR).arg(error));
 }
 
+void UbuntuDeviceHelper::onStdOut(const QString &stdout)
+{
+    QString message = stdout;
+    message.replace(QChar::fromLatin1('\n'),QLatin1String("<br/>"));
+    addToLog(message);
+}
+
 void UbuntuDeviceHelper::detect()
 {
     //start feature detection
@@ -297,13 +420,17 @@ void UbuntuDeviceHelper::detect()
 void UbuntuDeviceHelper::detectOpenSsh()
 {
     setProcessState(UbuntuDevice::DetectOpenSSH);
+
+    m_dev->m_hasOpenSSHServer = UbuntuDevice::Unknown;
+    emit featureDetected();
+
     beginAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_DETECTOPENSSH));
 
     stopProcess();
 
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_DETECTOPENSSH_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 void UbuntuDeviceHelper::startSshService()
@@ -315,7 +442,7 @@ void UbuntuDeviceHelper::startSshService()
 
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_STARTSSHSERVICE_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 void UbuntuDeviceHelper::enableDeveloperMode()
@@ -323,11 +450,14 @@ void UbuntuDeviceHelper::enableDeveloperMode()
     setProcessState(UbuntuDevice::InstallOpenSSH);
     beginAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_SSH_INSTALL));
 
+    m_dev->m_hasOpenSSHServer = UbuntuDevice::Unknown;
+    emit featureDetected();
+
     stopProcess();
 
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_SSH_INSTALL_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 void UbuntuDeviceHelper::disableDeveloperMode()
@@ -335,11 +465,14 @@ void UbuntuDeviceHelper::disableDeveloperMode()
     setProcessState(UbuntuDevice::RemoveOpenSSH);
     beginAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_SSH_REMOVE));
 
+    m_dev->m_hasOpenSSHServer = UbuntuDevice::Unknown;
+    emit featureDetected();
+
     stopProcess();
 
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_SSH_REMOVE_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 void UbuntuDeviceHelper::detectHasNetworkConnection()
@@ -348,13 +481,17 @@ void UbuntuDeviceHelper::detectHasNetworkConnection()
     //          adb shell nmcli dev list iface <intfc> | grep IP4.ADDRESS
     //      to find out the devices ip address
     setProcessState(UbuntuDevice::DetectNetworkConnection);
+
+    m_dev->m_hasNetworkConnection = UbuntuDevice::Unknown;
+    emit featureDetected();
+
     beginAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_HASNETWORK));
 
     stopProcess();
 
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_HASNETWORK_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 void UbuntuDeviceHelper::detectDeviceVersion()
@@ -366,43 +503,56 @@ void UbuntuDeviceHelper::detectDeviceVersion()
 
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_DETECTDEVICEVERSION_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 void UbuntuDeviceHelper::detectDeviceWritableImage()
 {
     setProcessState(UbuntuDevice::DetectDeviceWriteableImage);
+
+    m_dev->m_hasWriteableImage = UbuntuDevice::Unknown;
+    emit featureDetected();
+
     beginAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_DETECTWRITABLEIMAGE));
 
     stopProcess();
 
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_DETECTWRITABLEIMAGE_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 void UbuntuDeviceHelper::detectDeveloperTools()
 {
     setProcessState(UbuntuDevice::DetectDeveloperTools);
+
+    m_dev->m_hasDeveloperTools = UbuntuDevice::Unknown;
+    emit featureDetected();
+
     beginAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_DETECTDEVELOPERTOOLS));
 
     stopProcess();
 
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_DETECTDEVELOPERTOOLS_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 void UbuntuDeviceHelper::deviceConnected()
 {
-    qDebug()<<"Device "<<m_dev->id().toString()<<" connected";
+    if(debug) qDebug()<<"Device "<<m_dev->id().toString()<<" connected";
+
     ProjectExplorer::DeviceManager::instance()->setDeviceState(m_dev->id(),ProjectExplorer::IDevice::DeviceConnected);
-    detect();
+
+    if(m_dev->machineType() == ProjectExplorer::IDevice::Emulator)
+        waitForEmulatorStart();
+    else
+        waitForBoot();
 }
 
 void UbuntuDeviceHelper::deviceDisconnected()
 {
-    qDebug()<<"Device "<<m_dev->id().toString()<<" disconnected";
+    if(debug) qDebug()<<"Device "<<m_dev->id().toString()<<" disconnected";
     ProjectExplorer::DeviceManager::instance()->setDeviceState(m_dev->id(),ProjectExplorer::IDevice::DeviceDisconnected);
 
     setProcessState(UbuntuDevice::NotStarted);
@@ -420,9 +570,11 @@ void UbuntuDeviceHelper::readProcessOutput(QProcess *proc)
     QString msg;
     if (!stderr.isEmpty()) {
         msg.append(stderr);
+        onError(stderr);
     }
     if (!stdout.isEmpty()) {
         msg.append(stdout);
+        onStdOut(stdout);
     }
 
     if(!msg.isEmpty())
@@ -450,16 +602,16 @@ void UbuntuDeviceHelper::addToLog(const QString &msg)
 
 void UbuntuDeviceHelper::setProcessState(const int newState)
 {
-    Q_ASSERT_X(newState >= UbuntuDevice::NotStarted && newState <= UbuntuDevice::Done,
+    Q_ASSERT_X(newState >= UbuntuDevice::NotStarted && newState <= UbuntuDevice::MaxState,
                Q_FUNC_INFO,
                "State variable out of bounds");
 
     if( newState == m_dev->m_processState)
         return;
 
-    if(m_dev->m_processState == UbuntuDevice::NotStarted || m_dev->m_processState == UbuntuDevice::Done)
+    if(m_dev->m_processState == UbuntuDevice::NotStarted || m_dev->m_processState == UbuntuDevice::Done || m_dev->m_processState == UbuntuDevice::Failed)
         emit beginQueryDevice();
-    else if((newState == UbuntuDevice::Done || newState == UbuntuDevice::NotStarted))
+    else if((newState == UbuntuDevice::Done || newState == UbuntuDevice::NotStarted || newState == UbuntuDevice::Failed))
         emit endQueryDevice();
 
     m_dev->m_processState = static_cast<UbuntuDevice::ProcessState>(newState);
@@ -491,7 +643,7 @@ void UbuntuDeviceHelper::cloneTimeConfig()
 
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_CLONETIME_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 void UbuntuDeviceHelper::enableRWImage()
@@ -503,9 +655,12 @@ void UbuntuDeviceHelper::enableRWImage()
     beginAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_MAKEFSWRITABLE));
     stopProcess();
 
+    m_dev->m_hasWriteableImage = UbuntuDevice::Unknown;
+    emit featureDetected();
+
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_MAKEFSWRITABLE_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 void UbuntuDeviceHelper::disableRWImage()
@@ -517,9 +672,12 @@ void UbuntuDeviceHelper::disableRWImage()
     beginAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_MAKEFSREADONLY));
     stopProcess();
 
+    m_dev->m_hasWriteableImage = UbuntuDevice::Unknown;
+    emit featureDetected();
+
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_MAKEFSREADONLY_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 /*!
@@ -536,7 +694,7 @@ void UbuntuDeviceHelper::enablePortForward()
     stopProcess();
 
     if(!m_dev->m_localForwardedPorts.hasMore()) {
-        m_dev->m_localForwardedPorts = UbuntuLocalPortsManager::getFreeRange(m_dev->id().toSetting().toString(),20);
+        m_dev->m_localForwardedPorts = UbuntuLocalPortsManager::getFreeRange(m_dev->serialNumber(),20);
         if(!m_dev->m_localForwardedPorts.hasMore()) {
             //Oh noes , no ports available
 
@@ -565,9 +723,9 @@ void UbuntuDeviceHelper::enablePortForward()
     QString deviceSshPort = QString::number(connParms.port);
 
     QStringList args = QStringList()
-            << m_dev->id().toSetting().toString()
+            << m_dev->serialNumber()
             <<deviceSshPort
-            <<ports;
+           <<ports;
 
     QProcess adb;
     adb.start(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_PORTFORWARD_SCRIPT)
@@ -589,9 +747,12 @@ void UbuntuDeviceHelper::installDevTools()
     beginAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_ENABLEPLATFORMDEVELOPMENT));
     stopProcess();
 
+    m_dev->m_hasDeveloperTools = UbuntuDevice::Unknown;
+    emit featureDetected();
+
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_ENABLEPLATFORMDEVELOPMENT_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 void UbuntuDeviceHelper::removeDevTools()
@@ -604,9 +765,12 @@ void UbuntuDeviceHelper::removeDevTools()
     beginAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_DISABLEPLATFORMDEVELOPMENT));
     stopProcess();
 
+    m_dev->m_hasDeveloperTools = UbuntuDevice::Unknown;
+    emit featureDetected();
+
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_DISABLEPLATFORMDEVELOPMENT_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 void UbuntuDeviceHelper::deployPublicKey()
@@ -623,29 +787,36 @@ void UbuntuDeviceHelper::deployPublicKey()
     stopProcess();
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_SETUP_PUBKEY_AUTH_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString())
+                 .arg(m_dev->serialNumber())
                  .arg(deviceUsername));
 }
 
 void UbuntuDeviceHelper::cloneNetwork()
 {
     m_clonedNwCount++;
+
     setProcessState(UbuntuDevice::CloneNetwork);
     beginAction(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_CLONENETWORK));
 
+    m_dev->m_hasNetworkConnection = UbuntuDevice::Unknown;
+    emit featureDetected();
+
     stopProcess();
     startProcess(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_CLONENETWORK_SCRIPT)
                  .arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
-                 .arg(m_dev->id().toSetting().toString()));
+                 .arg(m_dev->serialNumber()));
 }
 
 void UbuntuDeviceHelper::startProcess(const QString &command)
 {
+    if(debug) qDebug()<<"Starting process: "<<command;
+
     if(!m_process) {
         m_process = new QProcess(this);
         connect(m_process,SIGNAL(readyRead()),this,SLOT(onProcessReadyRead()));
         connect(m_process,SIGNAL(finished(int)),this,SLOT(onProcessFinished(int)));
         connect(m_process,SIGNAL(error(QProcess::ProcessError)),this,SLOT(onProcessError(QProcess::ProcessError)));
+        connect(m_process,SIGNAL(stateChanged(QProcess::ProcessState)),this,SLOT(onProcessStateChanged(QProcess::ProcessState)));
     }
     m_process->setWorkingDirectory(QCoreApplication::applicationDirPath());
     m_process->start(command);
@@ -658,23 +829,42 @@ void UbuntuDeviceHelper::onProcessReadyRead()
 
 void UbuntuDeviceHelper::onProcessFinished(const int code)
 {
-    if (code != 0) {
-        onError(QString::fromLocal8Bit(m_process->readAll()));
-        processFinished(m_process->program(), code);
-        return;
-    }
     QString errorMsg = QString::fromLocal8Bit(m_process->readAllStandardError());
     if (errorMsg.trimmed().length()>0) onError(errorMsg);
     QString msg = QString::fromLocal8Bit(m_process->readAllStandardOutput());
     if (msg.trimmed().length()>0) onMessage(msg);
 
-    processFinished(QString(),code);
+    processFinished(m_process->program(),code);
 }
 
 void UbuntuDeviceHelper::onProcessError(const QProcess::ProcessError error)
 {
-    //if (m_process->exitCode() == 0) { return; }
-    onError(QString(QLatin1String("ERROR: (%0) %1 %2")).arg(m_process->program()).arg(m_process->errorString()).arg(error));
+    QString errorString = QStringLiteral("ERROR: (%0) %1 %2").arg(m_process->program()).arg(m_process->errorString()).arg(error);
+
+    if(debug) qDebug()<<"Received Process Error: "<<error<<errorString;
+
+    onError(errorString);
+}
+
+void UbuntuDeviceHelper::onProcessStateChanged(QProcess::ProcessState newState)
+{
+    if(!debug)
+        return;
+
+    switch(newState) {
+        case QProcess::NotRunning: {
+            if(debug) qDebug()<<QStringLiteral("Process not running");
+            break;
+        }
+        case QProcess::Starting: {
+            if(debug) qDebug()<<QStringLiteral("Process starting");
+            break;
+        }
+        case QProcess::Running: {
+            if(debug) qDebug()<<QStringLiteral("Process running");
+            break;
+        }
+    }
 }
 
 void UbuntuDeviceHelper::beginAction(QString msg) {
@@ -694,14 +884,15 @@ UbuntuDevice::UbuntuDevice()
     loadDefaultConfig();
 }
 
-UbuntuDevice::UbuntuDevice(const QString &name, ProjectExplorer::IDevice::MachineType machineType, ProjectExplorer::IDevice::Origin origin, Core::Id id)
-    : LinuxDevice(name,Core::Id(Constants::UBUNTU_DEVICE_TYPE_ID),machineType,origin,id)
+UbuntuDevice::UbuntuDevice(const QString &name, ProjectExplorer::IDevice::MachineType machineType, ProjectExplorer::IDevice::Origin origin, Core::Id id, const QString &architecture)
+    : LinuxDevice(name,Core::Id(Constants::UBUNTU_DEVICE_TYPE_ID).withSuffix(architecture),machineType,origin,id)
     , m_helper(new UbuntuDeviceHelper(this))
     , m_processState(NotStarted)
+    , m_scaleFactor(QStringLiteral("1.0"))
+    , m_memory(QStringLiteral("512"))
 {
     setDeviceState(ProjectExplorer::IDevice::DeviceStateUnknown);
     loadDefaultConfig();
-    setupPrivateKey();
     m_helper->init();
 }
 
@@ -709,10 +900,16 @@ UbuntuDevice::UbuntuDevice(const UbuntuDevice &other)
     : LinuxDevice(other)
     , m_helper(new UbuntuDeviceHelper(this))
     , m_processState(NotStarted)
-    , m_deviceInfoString(other.deviceInfoString())
+    , m_deviceInfo(other.m_deviceInfo)
+    , m_modelInfo(other.m_modelInfo)
+    , m_productInfo(other.m_productInfo)
+    , m_ubuntuVersion(other.m_ubuntuVersion)
+    , m_deviceVersion(other.m_deviceVersion)
+    , m_imageVersion(other.m_imageVersion)
+    , m_scaleFactor(other.m_scaleFactor)
+    , m_memory(other.m_memory)
 {
     setDeviceState(ProjectExplorer::IDevice::DeviceDisconnected);
-    setupPrivateKey();
     m_helper->init();
 }
 
@@ -747,7 +944,7 @@ void UbuntuDevice::setupPrivateKey()
         return;
 
     QSsh::SshConnectionParameters params = this->sshParameters();
-    params.privateKeyFile = QString::fromLatin1(Constants::UBUNTU_DEVICE_SSHIDENTITY).arg(QDir::homePath()).arg(id().toSetting().toString());
+    params.privateKeyFile = QString::fromLatin1(Constants::UBUNTU_DEVICE_SSHIDENTITY).arg(QDir::homePath());
 
     setSshParameters(params);
 }
@@ -764,6 +961,9 @@ UbuntuDevice::Ptr UbuntuDevice::create()
 
 QString UbuntuDevice::serialNumber() const
 {
+    if(machineType() == Emulator)
+        return m_emulatorSerial;
+
     return id().toSetting().toString();
 }
 
@@ -772,6 +972,11 @@ UbuntuDeviceHelper *UbuntuDevice::helper() const
     return m_helper;
 }
 
+void UbuntuDevice::cloneNetwork()
+{
+    m_helper->cloneNetwork();
+}
+
 /*!
  * \brief UbuntuDevice::openTerminal
  * Opens a detached terminal, logged into the device
@@ -781,7 +986,7 @@ void UbuntuDevice::openTerminal()
     QProcess p;
 
     QStringList args = QStringList()
-            << id().toSetting().toString()
+            << serialNumber()
             << QString::number(sshParameters().port)
             << sshParameters().userName
             << sshParameters().host;
@@ -806,7 +1011,7 @@ void UbuntuDevice::shutdown()
 {
     QProcess p;
     QStringList args = QStringList()
-            << id().toSetting().toString();
+            << serialNumber();
 
     //no need to redetect this should happen automagically
     p.startDetached(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_SHUTDOWN_SCRIPT).arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
@@ -818,14 +1023,14 @@ void UbuntuDevice::reboot()
 {
     QProcess p;
     QStringList args = QStringList()
-            << id().toSetting().toString();
+            << serialNumber();
 
     //no need to redetect this should happen automagically
     bool started = p.startDetached(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_REBOOT_SCRIPT).arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
                                    , args
                                    , QCoreApplication::applicationDirPath());
 
-    if(!started) {
+    if(!started && debug) {
         qDebug()<<"Could not start process "
                <<QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_REBOOT_SCRIPT).arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
               <<args
@@ -838,7 +1043,7 @@ void UbuntuDevice::rebootToRecovery()
 {
     QProcess p;
     QStringList args = QStringList()
-            << id().toSetting().toString();
+            << serialNumber();
 
     //no need to redetect this should happen automagically
     p.startDetached(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_REBOOT_TO_RECOVERY_SCRIPT).arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
@@ -850,7 +1055,7 @@ void UbuntuDevice::rebootToBootloader()
 {
     QProcess p;
     QStringList args = QStringList()
-            << id().toSetting().toString();
+            << serialNumber();
 
     //no need to redetect this should happen automagically
     p.startDetached(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_REBOOT_TO_BOOTLOADER_SCRIPT).arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
@@ -898,14 +1103,74 @@ void UbuntuDevice::setDeveloperToolsInstalled(const bool installed)
         m_helper->removeDevTools();
 }
 
-void UbuntuDevice::setDeviceInfoString(const QString &info)
+void UbuntuDevice::setDeviceInfo(const QString &productInfo, const QString &modelInfo, const QString &deviceInfo)
 {
-    m_deviceInfoString = info;
+    m_productInfo = productInfo;
+    m_modelInfo = modelInfo;
+    m_deviceInfo = deviceInfo;
+    emit m_helper->deviceInfoUpdated();
 }
 
-QString UbuntuDevice::deviceInfoString() const
+QString UbuntuDevice::modelInfo() const
 {
-    return m_deviceInfoString;
+    return m_modelInfo;
+}
+
+QString UbuntuDevice::deviceInfo() const
+{
+    return m_deviceInfo;
+}
+
+QString UbuntuDevice::productInfo() const
+{
+    return m_productInfo;
+}
+
+void UbuntuDevice::setEmulatorInfo(const QString &ubuntuVersion, const QString &deviceVersion, const QString &imageVersion)
+{
+    m_ubuntuVersion = ubuntuVersion;
+    m_deviceVersion = deviceVersion;
+    m_imageVersion  = imageVersion;
+    emit m_helper->deviceInfoUpdated();
+}
+
+QString UbuntuDevice::ubuntuVersion() const
+{
+    return m_ubuntuVersion;
+}
+
+QString UbuntuDevice::deviceVersion() const
+{
+    return m_deviceVersion;
+}
+
+QString UbuntuDevice::imageVersion() const
+{
+    return m_imageVersion;
+}
+
+bool UbuntuDevice::startEmulator()
+{
+    if ( machineType() != IDevice::Emulator )
+        return false;
+
+    QStringList args = QStringList() << imageName() << m_memory << m_scaleFactor;
+    return QProcess::startDetached(QString::fromLatin1(Constants::UBUNTUDEVICESWIDGET_LOCAL_START_EMULATOR_SCRIPT).arg(Ubuntu::Constants::UBUNTU_SCRIPTPATH)
+                            ,args
+                            ,QCoreApplication::applicationDirPath());
+}
+
+
+QString UbuntuDevice::imageName() const
+{
+    return id().toSetting().toString();
+}
+
+QString UbuntuDevice::architecture() const
+{
+    QString arch = this->type().suffixAfter(Constants::UBUNTU_DEVICE_TYPE_ID);
+    if(debug) qDebug()<<"Reporting device architecture as: "<<arch;
+    return arch;
 }
 
 UbuntuDevice::FeatureState UbuntuDevice::hasNetworkConnection() const
@@ -933,6 +1198,10 @@ QString UbuntuDevice::detectionStateString( ) const
     switch (m_processState) {
         case NotStarted:
             return tr("");
+        case WaitForEmulatorStart:
+            return tr("Waiting for the emulator to start up");
+        case WaitForBoot:
+            return tr("Waiting for the device to finish booting");
         case DetectDeviceVersion:
             return tr("Detecting device version");
         case DetectNetworkConnection:
@@ -968,14 +1237,47 @@ QString UbuntuDevice::detectionStateString( ) const
         case RemoveDevTools:
             return tr("Removing development tools");
         case Done:
-            return tr("Finished");
+            return tr("Ready");
+        case Failed:
+            return tr("Detection failed");
     }
     return QString();
 }
 
+QString UbuntuDevice::scaleFactor() const
+{
+    return m_scaleFactor;
+}
+
+bool UbuntuDevice::setScaleFactor(const QString &factor)
+{
+    if(supportedScaleFactors.contains(factor)) {
+        m_scaleFactor = factor;
+        emit m_helper->deviceInfoUpdated();
+        return true;
+    }
+    return false;
+}
+
+QString UbuntuDevice::memorySetting() const
+{
+    return m_memory;
+}
+
+bool UbuntuDevice::setMemorySetting(const QString &memory)
+{
+    if(supportedMemorySettings.contains(memory)) {
+        m_memory = memory;
+        emit m_helper->deviceInfoUpdated();
+        return true;
+    }
+    return false;
+}
+
 ProjectExplorer::IDeviceWidget *UbuntuDevice::createWidget()
 {
-    return new UbuntuDeviceConfigurationWidget(sharedFromThis());
+    return new RemoteLinux::GenericLinuxDeviceConfigurationWidget(sharedFromThis());
+    //return new UbuntuDeviceConfigurationWidget(sharedFromThis());
 }
 
 QList<Core::Id> UbuntuDevice::actionIds() const
@@ -985,7 +1287,7 @@ QList<Core::Id> UbuntuDevice::actionIds() const
 
 QString UbuntuDevice::displayType() const
 {
-    return tr("Ubuntu Device");
+    return tr("Ubuntu Device (%1)").arg(architecture());
 }
 
 ProjectExplorer::IDevice::Ptr  UbuntuDevice::clone() const
@@ -996,17 +1298,27 @@ ProjectExplorer::IDevice::Ptr  UbuntuDevice::clone() const
 void UbuntuDevice::fromMap(const QVariantMap &map)
 {
     LinuxDevice::fromMap(map);
-    if(map.contains(DEVICE_INFO_KEY))
-        m_deviceInfoString = map[DEVICE_INFO_KEY].toString();
 
-    setupPrivateKey();
+    if(map.contains(DEVICE_SCALE_FACTOR)) {
+        m_scaleFactor = map[DEVICE_SCALE_FACTOR].toString();
+        if(!supportedScaleFactors.contains(m_scaleFactor))
+            m_scaleFactor = QStringLiteral("1.0");
+    }
+    if(map.contains(DEVICE_MEMORY_SETTING)) {
+        m_memory = map[DEVICE_MEMORY_SETTING].toString();
+
+        if(!supportedMemorySettings.contains(m_memory))
+            m_memory = QStringLiteral("512");
+    }
+
     m_helper->init();
 }
 
 QVariantMap UbuntuDevice::toMap() const
 {
     QVariantMap map = LinuxDevice::toMap();
-    map.insert(DEVICE_INFO_KEY,m_deviceInfoString);
+    map.insert(DEVICE_SCALE_FACTOR,m_scaleFactor);
+    map.insert(DEVICE_MEMORY_SETTING,m_memory);
     return map;
 }
 
@@ -1015,6 +1327,12 @@ ProjectExplorer::DeviceProcess *UbuntuDevice::createProcess(QObject *parent) con
     return new UbuntuDeviceProcess(sharedFromThis(), parent);
 }
 
+ProjectExplorer::DeviceProcessSignalOperation::Ptr UbuntuDevice::signalOperation() const
+{
+    UbuntuDeviceSignalOperation::Ptr p(new UbuntuDeviceSignalOperation(sharedFromThis()));
+    return p;
+}
+
 UbuntuDevice::Ptr UbuntuDevice::sharedFromThis()
 {
     return qSharedPointerCast<UbuntuDevice>(LinuxDevice::sharedFromThis());
@@ -1025,9 +1343,9 @@ UbuntuDevice::ConstPtr UbuntuDevice::sharedFromThis() const
     return qSharedPointerCast<const UbuntuDevice>(LinuxDevice::sharedFromThis());
 }
 
-UbuntuDevice::Ptr UbuntuDevice::create(const QString &name, const QString& serial, ProjectExplorer::IDevice::MachineType machineType, ProjectExplorer::IDevice::Origin origin)
+UbuntuDevice::Ptr UbuntuDevice::create(const QString &name, const QString& serial, ProjectExplorer::IDevice::MachineType machineType, const QString &archName, ProjectExplorer::IDevice::Origin origin)
 {
-    return Ptr(new UbuntuDevice(name,machineType,origin,Core::Id::fromSetting(serial)));
+    return Ptr(new UbuntuDevice(name,machineType,origin,Core::Id::fromSetting(serial),archName));
 }
 
 //////////////
@@ -1053,32 +1371,29 @@ void UbuntuDeviceProcess::terminate()
 
 QString UbuntuDeviceProcess::fullCommandLine() const
 {
+    //return QStringLiteral("%1 %2").arg(quote(executable()),Utils::QtcProcess::joinArgsUnix(arguments()));
+
     QStringList rcFiles = QStringList()
             << QLatin1String("/etc/profile")
             << QLatin1String("$HOME/.profile")
             << QLatin1String("$HOME/.bashrc");
 
-    QStringList confFiles = QStringList()<<QString::fromLatin1("/etc/ubuntu-touch-session.d/$(getprop ro.product.device).conf");
-    QString fullCommandLine = QString::fromLatin1("test -f %1 && for myenv in $(cat  %1); do `echo \"export\" $myenv`; done ;").arg(confFiles[0]);
-
+    QString fullCommandLine;
     foreach (const QString &filePath, rcFiles)
         fullCommandLine += QString::fromLatin1("test -f %1 && . %1;").arg(filePath);
     if (!m_workingDir.isEmpty()) {
         fullCommandLine.append(QLatin1String("cd ")).append(quote(m_workingDir))
                 .append(QLatin1String(" && "));
     }
-    const QString envString = environment().toStringList().join(QLatin1String(" "));
-    if (!envString.isEmpty())
-        fullCommandLine.append(QLatin1Char(' ')).append(envString);
-    if (!fullCommandLine.isEmpty())
-        fullCommandLine += QLatin1Char(' ');
+
     fullCommandLine.append(quote(executable()));
     if (!arguments().isEmpty()) {
         fullCommandLine.append(QLatin1Char(' '));
-        fullCommandLine.append(Utils::QtcProcess::joinArgsUnix(arguments()));
+        fullCommandLine.append(Utils::QtcProcess::joinArgs(arguments(),Utils::OsTypeLinux));
     }
 
-    qDebug()<<fullCommandLine;
+    if(debug) qDebug()<<fullCommandLine;
+
     return fullCommandLine;
 }
 
