@@ -19,10 +19,11 @@
 #include "ubuntumenu.h"
 #include "ubuntushared.h"
 #include "ubuntuconstants.h"
-#include "ubuntudeviceswidget.h"
+#include "ubuntudevicemode.h"
 #include "ubuntuproject.h"
 #include "ubuntuclicktool.h"
 #include "ubuntudevice.h"
+#include "ubuntuclickmanifest.h"
 
 #include <coreplugin/icore.h>
 #include <coreplugin/icontext.h>
@@ -38,6 +39,8 @@
 #include <projectexplorer/compileoutputwindow.h>
 #include <projectexplorer/iprojectmanager.h>
 #include <projectexplorer/buildconfiguration.h>
+#include <projectexplorer/kitinformation.h>
+#include <projectexplorer/toolchain.h>
 #include <utils/qtcprocess.h>
 #include <ssh/sshconnection.h>
 
@@ -46,6 +49,7 @@
 #include <QMenu>
 #include <QInputDialog>
 #include <QDebug>
+#include <QVariantMap>
 #include <QMessageBox>
 
 #include <QJsonObject>
@@ -54,6 +58,10 @@
 using namespace Ubuntu;
 using namespace Ubuntu::Internal;
 
+enum {
+    debug = 0
+};
+
 UbuntuMenu *UbuntuMenu::m_instance = 0;
 
 UbuntuMenu *UbuntuMenu::instance()
@@ -82,7 +90,11 @@ UbuntuMenu::UbuntuMenu(QObject *parent) :
     connect(&m_ubuntuProcess,SIGNAL(error(QString)),this,SLOT(onError(QString)));
 
     connect(ProjectExplorer::ProjectExplorerPlugin::instance(),SIGNAL(updateRunActions()),this,SLOT(slotUpdateActions()));
-    connect(UbuntuDevicesWidget::instance(),SIGNAL(updateDeviceActions()),this,SLOT(slotUpdateActions()));
+    connect(UbuntuDeviceMode::instance(),SIGNAL(updateDeviceActions()),this,SLOT(slotUpdateActions()));
+
+    ProjectExplorer::ProjectExplorerPlugin *projectExplorer = ProjectExplorer::ProjectExplorerPlugin::instance();
+    connect(projectExplorer, SIGNAL(aboutToShowContextMenu(ProjectExplorer::Project*,ProjectExplorer::Node*)),
+            this, SLOT(setContextMenuProject(ProjectExplorer::Project*)));
 }
 
 
@@ -92,6 +104,7 @@ void UbuntuMenu::slotUpdateActions() {
     bool isQmakeProject = false;
     bool isUbuntuProject = false;
     bool isUbuntuHtmlProject = false;
+    bool isClickTarget = false;
 
     if (startupProject) {
         isQmlProject = (startupProject->projectManager()->mimeType() == QLatin1String(Constants::QMLPROJECT_MIMETYPE));
@@ -99,11 +112,15 @@ void UbuntuMenu::slotUpdateActions() {
         isUbuntuProject = (startupProject->projectManager()->mimeType() == QLatin1String(Constants::UBUNTUPROJECT_MIMETYPE));
         isUbuntuHtmlProject = isProperUbuntuHtmlProject(startupProject);
         isUbuntuProject = isUbuntuProject || isUbuntuHtmlProject || isQmlProject;
+        isClickTarget = startupProject->activeTarget()
+                && startupProject->activeTarget()->kit()
+                && ProjectExplorer::ToolChainKitInformation::toolChain(startupProject->activeTarget()->kit())
+                && ProjectExplorer::ToolChainKitInformation::toolChain(startupProject->activeTarget()->kit())->type() == QLatin1String(Constants::UBUNTU_CLICK_TOOLCHAIN_ID);
     }
 
     //bool canRun = projectExplorerInstance->canRun(startupProject,ProjectExplorer::NormalRunMode);
     bool projectOpen = (startupProject!=NULL);
-    bool deviceDetected = UbuntuDevicesWidget::instance()->deviceDetected();
+    bool deviceDetected = !UbuntuDeviceMode::instance()->device().isNull();
 
     foreach(QAction* act, m_actions) {
         bool requiresDevice = act->property(Constants::UBUNTU_MENUJSON_DEVICEREQUIRED).toBool();
@@ -112,13 +129,14 @@ void UbuntuMenu::slotUpdateActions() {
         bool requiresQmakeProject = act->property(Constants::UBUNTU_MENUJSON_QMAKEPROJECTREQUIRED).toBool();
         bool requiresUbuntuProject = act->property(Constants::UBUNTU_MENUJSON_UBUNTUPROJECTREQUIRED).toBool();
         bool requiresUbuntuHtmlProject = act->property(Constants::UBUNTU_MENUJSON_UBUNTUHTMLPROJECTREQUIRED).toBool();
+        bool requiresClickToolchain = act->property(Constants::UBUNTU_MENUJSON_CLICKTOOLCHAINREQUIRED).toBool();
         bool actionEnabled = ( (requiresQmakeProject ? isQmakeProject : true) &&
                                (requiresQmlProject ? isQmlProject : true) &&
                                (requiresUbuntuHtmlProject ? isUbuntuHtmlProject : true) &&
                                (requiresDevice ? deviceDetected : true) &&
                                (requiresProject ? projectOpen : true) &&
-                               (requiresUbuntuProject ? isUbuntuProject : true));
-
+                               (requiresUbuntuProject ? isUbuntuProject : true) &&
+                               (requiresClickToolchain ? isClickTarget : true) );
         act->setEnabled( actionEnabled );
     }
 }
@@ -145,6 +163,63 @@ void UbuntuMenu::onFinished(const QProcess *programm, QString cmd, int)
     emit finished_action(programm,cmd);
 }
 
+void UbuntuMenu::createManifestFile()
+{
+    if(Q_UNLIKELY(!m_ctxMenuProject))
+        return;
+
+    bool changed = false;
+
+    QString manifestFilePath = m_ctxMenuProject->projectDirectory()+QDir::separator()+QLatin1String("manifest.json");
+
+    UbuntuClickManifest manifest;
+    if(QFile::exists(manifestFilePath)) {
+        if(!manifest.load(manifestFilePath)) {
+            QMessageBox::warning(Core::ICore::mainWindow(),tr("Error"),
+                                 tr("The manifest.json file already exists, but can not be opened."));
+            return;
+        }
+    } else {
+        if(!manifest.load(QLatin1String(Constants::UBUNTUPACKAGINGWIDGET_DEFAULT_MANIFEST),m_ctxMenuProject.data())) {
+            QMessageBox::warning(Core::ICore::mainWindow(),tr("Error"),
+                                 tr("Could not open the manifest.json template"));
+            return;
+        }
+
+        changed = true;
+        manifest.setFileName(manifestFilePath);
+        manifest.save();
+    }
+
+    QList<UbuntuClickManifest::Hook> hooks = manifest.hooks();
+    foreach(const UbuntuClickManifest::Hook &hook, hooks) {
+        if(!hook.appArmorFile.isEmpty()) {
+            UbuntuClickManifest aaFile;
+            QString aaFilePath = QDir::cleanPath(m_ctxMenuProject->projectDirectory()+QDir::separator()+hook.appArmorFile);
+            if(QFile::exists(aaFilePath))
+                continue;
+
+            if(!aaFile.load(QLatin1String(Constants::UBUNTUPACKAGINGWIDGET_DEFAULT_MYAPP))) {
+                printToOutputPane(tr("Could not open the apparmor template"));
+                continue;
+            }
+            changed = true;
+            aaFile.setFileName(aaFilePath);
+            aaFile.save();
+        }
+    }
+
+    QMessageBox::information(Core::ICore::mainWindow(),
+                             tr("Files created"),
+                             changed ? tr("The manifest.json and apparmor files have been created in the project directory.\nPlease make sure to add them to your project file.")
+                                     : tr("All required files already exist in your project directory"));
+}
+
+void UbuntuMenu::setContextMenuProject(ProjectExplorer::Project *p)
+{
+    m_ctxMenuProject = p;
+}
+
 QString UbuntuMenu::menuPath(QString fileName) {
     return Constants::UBUNTU_MENUPATH + fileName;
 }
@@ -153,12 +228,12 @@ QJsonDocument UbuntuMenu::getMenuJSON() {
     QByteArray contents;
     QString errorMsg;
     if (readFile(menuPath(QLatin1String(Constants::UBUNTU_MENUJSON)),&contents, &errorMsg) == false) {
-        qDebug() << __PRETTY_FUNCTION__ << errorMsg;
+        qWarning() << __PRETTY_FUNCTION__ << errorMsg;
     }
     QJsonParseError error;
     QJsonDocument retval = QJsonDocument::fromJson(contents,&error);
     if (error.error != QJsonParseError::NoError) {
-        qDebug() << error.errorString();
+        qWarning() << error.errorString();
     }
     return retval;
 }
@@ -206,6 +281,7 @@ void UbuntuMenu::parseMenu(QJsonObject obj, Core::ActionContainer*& parent, cons
         bool actionUbuntuHtmlProjectRequired = false;
         bool actionSaveRequired = false;
         bool clickTargetRequired = false;
+        bool clickToolchainRequired = false;
 
         if (obj.contains(QLatin1String(Constants::UBUNTU_MENUJSON_NAME))) {
             actionName = obj.value(QLatin1String(Constants::UBUNTU_MENUJSON_NAME)).toString();
@@ -261,6 +337,9 @@ void UbuntuMenu::parseMenu(QJsonObject obj, Core::ActionContainer*& parent, cons
         if (obj.contains(QLatin1String(Constants::UBUNTU_MENUJSON_CLICKTARGETREQUIRED))) {
             clickTargetRequired = obj.value(QLatin1String(Constants::UBUNTU_MENUJSON_CLICKTARGETREQUIRED)).toBool();
         }
+        if (obj.contains(QLatin1String(Constants::UBUNTU_MENUJSON_CLICKTOOLCHAINREQUIRED))) {
+            clickToolchainRequired = obj.value(QLatin1String(Constants::UBUNTU_MENUJSON_CLICKTOOLCHAINREQUIRED)).toBool();
+        }
 
         if (obj.contains(QLatin1String(Constants::UBUNTU_MENUJSON_ACTIONS)) && obj.value(QLatin1String(Constants::UBUNTU_MENUJSON_ACTIONS)).isArray()) {
             QJsonValue actions = obj.value(QLatin1String(Constants::UBUNTU_MENUJSON_ACTIONS));
@@ -285,6 +364,7 @@ void UbuntuMenu::parseMenu(QJsonObject obj, Core::ActionContainer*& parent, cons
         act->setProperty(Constants::UBUNTU_MENUJSON_UBUNTUHTMLPROJECTREQUIRED,actionUbuntuHtmlProjectRequired);
         act->setProperty(Constants::UBUNTU_MENUJSON_SAVEREQUIRED,actionSaveRequired);
         act->setProperty(Constants::UBUNTU_MENUJSON_CLICKTARGETREQUIRED,clickTargetRequired);
+        act->setProperty(Constants::UBUNTU_MENUJSON_CLICKTOOLCHAINREQUIRED,clickToolchainRequired);
 
         connect(act, SIGNAL(triggered()), this, SLOT(menuItemTriggered()));
         m_actions.insert(Core::Id(actionId.toUtf8().constData()),act);
@@ -383,8 +463,8 @@ void UbuntuMenu::menuItemTriggered() {
                             }
 
                             queryData = QInputDialog::getText(Core::ICore::mainWindow(), queryDialogTitle,
-                                                                     queryDialogMessage, QLineEdit::Normal,
-                                                                     queryDialogValue, &bQueryOk);
+                                                              queryDialogMessage, QLineEdit::Normal,
+                                                              queryDialogValue, &bQueryOk);
 
                             // raise a flag that there is query data available for future actions
                             bQuery = true;
@@ -396,7 +476,7 @@ void UbuntuMenu::menuItemTriggered() {
                                 return;
                             }
                         }
-                    // check if messageDialog
+                        // check if messageDialog
                     } else if (obj.contains(QLatin1String(Constants::UBUNTU_MENUJSON_MESSAGEDIALOG))) {
                         QJsonValue messageDialog = obj.value(QLatin1String(Constants::UBUNTU_MENUJSON_MESSAGEDIALOG));
                         if (messageDialog.isObject()) {
@@ -413,10 +493,141 @@ void UbuntuMenu::menuItemTriggered() {
                             }
 
                             QMessageBox::information(Core::ICore::mainWindow(), messageDialogTitle,
-                                                                     messageDialogMessage);
+                                                     messageDialogMessage);
+                        }
+                        //check if metacall
+                    } else if (obj.contains(QLatin1String(Constants::UBUNTU_MENUJSON_METACALL))) {
+                        QJsonValue metaCall = obj.value(QLatin1String(Constants::UBUNTU_MENUJSON_METACALL));
+                        if (metaCall.isObject()) {
+                            QJsonObject metaCallObj = metaCall.toObject();
+                            QByteArray methodName;
+                            QList<QGenericArgument> args;
+                            if(!metaCallObj.contains(QLatin1String(Constants::UBUNTU_MENUJSON_METACALL_METHOD))) {
+                                qWarning()<<"Metacall menuitem does not contain a method name";
+                                return;
+                            }
+
+                            methodName = metaCallObj[QLatin1String(Constants::UBUNTU_MENUJSON_METACALL_METHOD)].toString().toLocal8Bit();
+                            if(methodName.isEmpty()){
+                                qWarning()<< "Property method of a metacall menuitem has to be a string and can not be empty";
+                                return;
+                            }
+
+                            //we first need to fill a list of variant values, otherwise we get dangling pointers in QGenericArgument
+                            //because of QVariants getting out of scope
+                            QVariantList varArgs;
+                            if(metaCallObj.contains(QLatin1String(Constants::UBUNTU_MENUJSON_METACALL_ARGS))) {
+                                QJsonArray arr = metaCallObj[QLatin1String(Constants::UBUNTU_MENUJSON_METACALL_ARGS)].toArray();
+                                foreach(const QJsonValue &val,arr) {
+                                    switch(val.type()) {
+                                        case QJsonValue::Undefined:
+                                        case QJsonValue::Null: {
+                                            qWarning()<<"Arguments of a metacall can not be null";
+                                            return;
+                                            break;
+                                        }
+                                        case QJsonValue::Bool:
+                                        case QJsonValue::Double:
+                                        case QJsonValue::String:
+                                        case QJsonValue::Array:
+                                        case QJsonValue::Object: {
+                                            varArgs.append(val.toVariant());
+                                            break;
+                                        }
+                                    }
+                                }
+                            }
+
+                            foreach(const QVariant &val,varArgs)
+                                args.append(QGenericArgument(val.typeName(),val.data()));
+
+                            bool ok = false;
+                            int argsCount = args.size();
+                            if (argsCount > 9) {
+                                ok = QMetaObject::invokeMethod(this,methodName.data(),
+                                                               (args.at(0)),
+                                                               (args.at(1)),
+                                                               (args.at(2)),
+                                                               (args.at(3)),
+                                                               (args.at(4)),
+                                                               (args.at(5)),
+                                                               (args.at(6)),
+                                                               (args.at(7)),
+                                                               (args.at(8)),
+                                                               (args.at(9)));
+                            } else if (argsCount > 8) {
+                                ok = QMetaObject::invokeMethod(this,methodName.data(),
+                                                               (args.at(0)),
+                                                               (args.at(1)),
+                                                               (args.at(2)),
+                                                               (args.at(3)),
+                                                               (args.at(4)),
+                                                               (args.at(5)),
+                                                               (args.at(6)),
+                                                               (args.at(7)),
+                                                               (args.at(8)));
+                            } else if (argsCount > 7) {
+                                ok = QMetaObject::invokeMethod(this,methodName.data(),
+                                                               (args.at(0)),
+                                                               (args.at(1)),
+                                                               (args.at(2)),
+                                                               (args.at(3)),
+                                                               (args.at(4)),
+                                                               (args.at(5)),
+                                                               (args.at(6)),
+                                                               (args.at(7)));
+                            } else if (argsCount > 6) {
+                                ok = QMetaObject::invokeMethod(this,methodName.data(),
+                                                               (args.at(0)),
+                                                               (args.at(1)),
+                                                               (args.at(2)),
+                                                               (args.at(3)),
+                                                               (args.at(4)),
+                                                               (args.at(5)),
+                                                               (args.at(6)));
+                            } else if (argsCount > 5) {
+                                ok = QMetaObject::invokeMethod(this,methodName.data(),
+                                                               (args.at(0)),
+                                                               (args.at(1)),
+                                                               (args.at(2)),
+                                                               (args.at(3)),
+                                                               (args.at(4)),
+                                                               (args.at(5)));
+                            } else if (argsCount > 4) {
+                                ok = QMetaObject::invokeMethod(this,methodName.data(),
+                                                               (args.at(0)),
+                                                               (args.at(1)),
+                                                               (args.at(2)),
+                                                               (args.at(3)),
+                                                               (args.at(4)));
+                            } else if (argsCount > 3) {
+                                ok = QMetaObject::invokeMethod(this,methodName.data(),
+                                                               (args.at(0)),
+                                                               (args.at(1)),
+                                                               (args.at(2)),
+                                                               (args.at(3)));
+                            } else if (argsCount > 2) {
+                                ok = QMetaObject::invokeMethod(this,methodName.data(),
+                                                               (args.at(0)),
+                                                               (args.at(1)),
+                                                               (args.at(2)));
+                            } else if (argsCount > 1) {
+                                ok = QMetaObject::invokeMethod(this,methodName.data(),
+                                                               (args.at(0)),
+                                                               (args.at(1)));
+                            } else if (argsCount > 0) {
+                                ok = QMetaObject::invokeMethod(this,methodName.data(),
+                                                               (args.at(0)));
+                            } else {
+                                ok = QMetaObject::invokeMethod(this,methodName.data());
+                            }
+
+                            if(!ok)
+                                qWarning()<<"Invoke of "<<methodName<<" with arguments "<<varArgs<<" failed";
+                            return;
                         }
                     }
-                // check if command
+                    // check if command
                 } else if (value.isString()) {
                     QString command = value.toString();
                     QString workingDirectory;
@@ -473,15 +684,31 @@ void UbuntuMenu::menuItemTriggered() {
 
                             workingDirectory = qtcBuildConfig->buildDirectory().toString();
                         }
+
+                        if(project->id() == Constants::GO_PROJECT_ID) {
+                            QVariant ret(QVariant::String);
+                            QGenericReturnArgument genRet(ret.typeName(),ret.data());
+                            if(QMetaObject::invokeMethod(project,"applicationNames",genRet)) {
+                                command = command.replace(QLatin1String(Constants::UBUNTU_GO_BUILD_TARGETS),ret.toString());
+                            }
+                        }
                     }
 
-                    UbuntuDevice::ConstPtr device = UbuntuDevicesWidget::instance()->device();
-                    if (device) {
-                        command = command.replace(QLatin1String(Constants::UBUNTU_ACTION_DEVICE_IP),device->sshParameters().host);
-                        command = command.replace(QLatin1String(Constants::UBUNTU_ACTION_DEVICE_USERNAME),device->sshParameters().userName);
-                        command = command.replace(QLatin1String(Constants::UBUNTU_ACTION_DEVICE_PORT),QString::number(device->sshParameters().port));
+                    bool requiresDevice = act->property(Constants::UBUNTU_MENUJSON_DEVICEREQUIRED).toBool();
+                    if(requiresDevice) {
+                        UbuntuDevice::ConstPtr device = UbuntuDeviceMode::instance()->device();
+                        if (device) {
+                            if( device->deviceState() != ProjectExplorer::IDevice::DeviceReadyToUse ) {
+                                QMessageBox::warning(Core::ICore::mainWindow(),tr("Device not ready"),tr("The currently selected device is not ready, please select another one on the devices mode"));
+                                return;
+                            }
 
-                        command = command.replace(QLatin1String(Constants::UBUNTU_ACTION_SERIALNUMBER),device->id().toSetting().toString());
+                            command = command.replace(QLatin1String(Constants::UBUNTU_ACTION_DEVICE_IP),device->sshParameters().host);
+                            command = command.replace(QLatin1String(Constants::UBUNTU_ACTION_DEVICE_USERNAME),device->sshParameters().userName);
+                            command = command.replace(QLatin1String(Constants::UBUNTU_ACTION_DEVICE_PORT),QString::number(device->sshParameters().port));
+
+                            command = command.replace(QLatin1String(Constants::UBUNTU_ACTION_SERIALNUMBER),device->serialNumber());
+                        }
                     }
                     command = command.replace(QLatin1String(Constants::UBUNTU_ACTION_SHAREDIRECTORY),Constants::UBUNTU_SHAREPATH);
                     command = command.replace(QLatin1String(Constants::UBUNTU_ACTION_SCRIPTDIRECTORY),Constants::UBUNTU_SCRIPTPATH);
@@ -491,6 +718,9 @@ void UbuntuMenu::menuItemTriggered() {
 
                     QStringList cmdList;
                     cmdList << command << workingDirectory;
+
+                    if(debug) qDebug()<<command;
+
                     m_ubuntuProcess.append(cmdList);
                 }
             }
