@@ -17,6 +17,7 @@
  */
 
 #include "ubuntupackagingmode.h"
+#include "ubuntupackagingmodel.h"
 #include "ubuntuconstants.h"
 
 #include <coreplugin/modemanager.h>
@@ -35,6 +36,12 @@
 
 #include <cmakeprojectmanager/cmakeprojectconstants.h>
 
+#include <QScrollArea>
+#include <QQuickView>
+#include <QQmlContext>
+#include <QQmlEngine>
+#include <QDebug>
+
 using namespace Ubuntu::Internal;
 
 UbuntuPackagingMode *UbuntuPackagingMode::m_instance = 0;
@@ -57,14 +64,22 @@ UbuntuPackagingMode::UbuntuPackagingMode(QObject *parent) :
     layout->setSpacing(0);
     m_modeWidget->setLayout(layout);
 
-
     Utils::StyledBar* styledBar = new Utils::StyledBar(m_modeWidget);
     layout->addWidget(styledBar);
-    QScrollArea *scrollArea = new QScrollArea(m_modeWidget);
-    scrollArea->setFrameShape(QFrame::NoFrame);
-    layout->addWidget(scrollArea);
-    scrollArea->setWidget(&m_ubuntuPackagingWidget);
-    scrollArea->setWidgetResizable(true);
+
+    m_modeView = new QQuickView;
+    m_modeView->setResizeMode(QQuickView::SizeRootObjectToView);
+    m_viewModel = new UbuntuPackagingModel(m_modeView);
+
+    QWidget* container = QWidget::createWindowContainer(m_modeView);
+    container->setMinimumWidth(860);
+    container->setMinimumHeight(548);
+    container->setFocusPolicy(Qt::TabFocus);
+    layout->addWidget(container);
+
+    m_modeView->rootContext()->setContextProperty(QLatin1String("publishModel") ,m_viewModel);
+    m_modeView->rootContext()->setContextProperty(QLatin1String("resourceRoot") ,Constants::UBUNTU_DEVICESCREEN_ROOT);
+    m_modeView->setSource(QUrl::fromLocalFile(Constants::UBUNTU_PUBLISHSCREEN_QML));
 
     connect(Core::ModeManager::instance(), SIGNAL(currentModeChanged(Core::IMode*)), SLOT(modeChanged(Core::IMode*)));
 
@@ -72,8 +87,7 @@ UbuntuPackagingMode::UbuntuPackagingMode(QObject *parent) :
     connect(sessionManager,SIGNAL(projectAdded(ProjectExplorer::Project*)),SLOT(on_projectAdded(ProjectExplorer::Project*)));
     connect(sessionManager,SIGNAL(projectRemoved(ProjectExplorer::Project*)),SLOT(on_projectRemoved(ProjectExplorer::Project*)));
     connect(sessionManager,SIGNAL(startupProjectChanged(ProjectExplorer::Project*)),SLOT(on_projectAdded(ProjectExplorer::Project*)));
-    connect(&m_ubuntuPackagingWidget,SIGNAL(reviewToolsInstalledChanged(bool)),this,SLOT(updateModeState()));
-
+    connect(m_viewModel,SIGNAL(reviewToolsInstalledChanged(bool)),this,SLOT(updateModeState()));
     setWidget(m_modeWidget);
     setEnabled(false);
 }
@@ -82,43 +96,7 @@ void UbuntuPackagingMode::initialize() {
 
 }
 
-UbuntuClickManifest *UbuntuPackagingMode::manifest()
-{
-    return m_instance->m_ubuntuPackagingWidget.manifest();
-}
-
-UbuntuClickManifest *UbuntuPackagingMode::appArmor()
-{
-    return m_instance->m_ubuntuPackagingWidget.appArmor();
-}
-
 void UbuntuPackagingMode::modeChanged(Core::IMode* currentMode) {
-    if (currentMode->id() == id()) {
-        ProjectExplorer::Project* startupProject = ProjectExplorer::SessionManager::startupProject();
-
-        bool isQmlProject = false;
-        bool isQmakeProject = false;
-        bool isUbuntuProject = false;
-        bool isCMakeProject = false;
-
-        if (startupProject) {
-            isQmlProject = (startupProject->projectManager()->mimeType() == QLatin1String(Constants::QMLPROJECT_MIMETYPE));
-            isQmakeProject = (startupProject->projectManager()->mimeType() == QLatin1String(Constants::QMAKE_MIMETYPE));
-            isUbuntuProject = (startupProject->projectManager()->mimeType() == QLatin1String(Constants::UBUNTUPROJECT_MIMETYPE));
-            isCMakeProject  = (startupProject->projectManager()->mimeType() == QLatin1String(CMakeProjectManager::Constants::CMAKEMIMETYPE));
-        }
-
-        if (isQmlProject || isUbuntuProject || isCMakeProject) {
-            m_ubuntuPackagingWidget.openManifestForProject();
-            m_ubuntuPackagingWidget.setAvailable(true);
-        } else {
-            m_ubuntuPackagingWidget.setAvailable(false);
-        }
-
-    } else if (previousMode == id()) {
-        m_ubuntuPackagingWidget.save();
-    }
-
     previousMode = currentMode->id();
 }
 
@@ -126,25 +104,21 @@ void UbuntuPackagingMode::updateModeState() {
     ProjectExplorer::Project* startupProject = ProjectExplorer::SessionManager::startupProject();
 
     bool isQmlProject = false;
-    bool isQmakeProject = false;
+    //bool isQmakeProject = false;
     bool isUbuntuProject = false;
     bool isCMakeProject = false;
-    bool reviewToolsInstalled = m_ubuntuPackagingWidget.reviewToolsInstalled();
+    bool isGoProject = false;
+    bool reviewToolsInstalled = m_viewModel->reviewToolsInstalled();
 
     if (startupProject) {
         isQmlProject = (startupProject->projectManager()->mimeType() == QLatin1String(Constants::QMLPROJECT_MIMETYPE));
-        isQmakeProject = (startupProject->projectManager()->mimeType() == QLatin1String(Constants::QMAKE_MIMETYPE));
+        //isQmakeProject = (startupProject->projectManager()->mimeType() == QLatin1String(Constants::QMAKE_MIMETYPE));
         isUbuntuProject = (startupProject->projectManager()->mimeType() == QLatin1String(Constants::UBUNTUPROJECT_MIMETYPE));
         isCMakeProject  = (startupProject->projectManager()->mimeType() == QLatin1String(CMakeProjectManager::Constants::CMAKEMIMETYPE));
+        isGoProject = (startupProject->projectManager()->mimeType() == QLatin1String(Constants::GO_PROJECT_MIMETYPE));
     }
 
-    this->setEnabled((isQmlProject || isUbuntuProject || isCMakeProject || reviewToolsInstalled));
-    if (this->isEnabled()) {
-        //save only if something was loaded
-        if(m_ubuntuPackagingWidget.openManifestForProject()) {
-            m_ubuntuPackagingWidget.save();
-        }
-    }
+    this->setEnabled((isQmlProject || isUbuntuProject || isCMakeProject || isGoProject || reviewToolsInstalled));
 }
 
 void UbuntuPackagingMode::on_projectAdded(ProjectExplorer::Project *project) {
