@@ -37,14 +37,11 @@
 #include "ubuntusettingsclickpage.h"
 
 #include <extensionsystem/iplugin.h>
-#include <QProcess>
 #include <coreplugin/mimedatabase.h>
 
 namespace Ubuntu {
 namespace Internal {
 
-class UbuntuClickManager;
-
 class UBUNTUSHARED_EXPORT UbuntuPlugin: public ExtensionSystem::IPlugin
 {
     Q_OBJECT
@@ -54,23 +51,27 @@ public:
     UbuntuPlugin();
     ~UbuntuPlugin();
 
-    virtual bool initialize(const QStringList &arguments, QString *errorString);
-    virtual void extensionsInitialized();
+    virtual bool initialize(const QStringList &arguments, QString *errorString) override;
+    virtual void extensionsInitialized() override;
 
 private slots:
     void onKitsLoaded ();
+    void showFirstStartWizard ();
+    void updateContextMenu(ProjectExplorer::Project *project,ProjectExplorer::Node *node);
+    void migrateProject ();
 
 protected:
-    UbuntuWelcomeMode*      m_ubuntuWelcomeMode;
-    UbuntuDeviceMode*       m_ubuntuDeviceMode;
-    UbuntuMenu*             m_ubuntuMenu;
-    UbuntuIRCMode*          m_ubuntuIRCMode;
-    UbuntuAPIMode*          m_ubuntuAPIMode;
-    UbuntuCoreAppsMode*     m_ubuntuCoreAppsMode;
-    UbuntuWikiMode*         m_ubuntuWikiMode;
-    UbuntuPackagingMode*    m_ubuntuPackagingMode;
-    UbuntuPastebinMode*     m_ubuntuPastebinMode;
-    UbuntuClickManager*     m_ubuntuClickManager;
+    UbuntuDeviceMode       *m_ubuntuDeviceMode;
+    UbuntuMenu             *m_ubuntuMenu;
+    UbuntuIRCMode          *m_ubuntuIRCMode;
+    UbuntuAPIMode          *m_ubuntuAPIMode;
+    UbuntuCoreAppsMode     *m_ubuntuCoreAppsMode;
+    UbuntuWikiMode         *m_ubuntuWikiMode;
+    UbuntuPackagingMode    *m_ubuntuPackagingMode;
+    UbuntuPastebinMode     *m_ubuntuPastebinMode;
+    QAction                *m_migrateProjectAction;
+
+    ProjectExplorer::Project *m_currentContextMenuProject;
 };
 
 
