@@ -50,6 +50,14 @@ namespace Internal {
 class UbuntuProjectManager;
 class UbuntuProjectFile;
 class UbuntuProjectNode;
+
+class UbuntuKitMatcher : public ProjectExplorer::KitMatcher
+{
+public:
+    explicit UbuntuKitMatcher() { }
+    bool matches(const ProjectExplorer::Kit *k) const override;
+};
+
 class UbuntuProject : public ProjectExplorer::Project
 {
     Q_OBJECT
@@ -57,13 +65,12 @@ class UbuntuProject : public ProjectExplorer::Project
 public:
     UbuntuProject(UbuntuProjectManager *manager, const QString &fileName);
 
-    QString displayName() const;
-    Core::Id id() const;
-    Core::IDocument *document() const;
-    ProjectExplorer::IProjectManager *projectManager() const;
+    QString displayName() const override;
+    Core::IDocument *document() const override;
+    ProjectExplorer::IProjectManager *projectManager() const override;
 
-    ProjectExplorer::ProjectNode *rootProjectNode() const;
-    QStringList files(FilesMode fileMode) const;
+    ProjectExplorer::ProjectNode *rootProjectNode() const override;
+    QStringList files(FilesMode fileMode) const override;
 
     QDir projectDir() const {
         return projectDirectory();
@@ -77,6 +84,14 @@ public:
         return m_mainFile;
     }
 
+    // Project interface
+    virtual bool supportsKit(ProjectExplorer::Kit *k, QString *errorMessage) const override;
+    virtual bool needsConfiguration() const override;
+    virtual bool supportsNoTargetPanel() const override;
+    virtual ProjectExplorer::KitMatcher *createRequiredKitMatcher() const override;
+    virtual ProjectExplorer::KitMatcher *createPreferredKitMatcher() const override;
+
+    static QString shadowBuildDirectory(const QString &proFilePath, const ProjectExplorer::Kit *k, const QString &suffix = QString());
 private:
     void extractProjectFileData(const QString& filename);
 
@@ -87,7 +102,6 @@ private:
 
     QString m_fileName;
     QSharedPointer<UbuntuProjectNode> m_rootNode;
-    
 };
 }
 }
